# QCI Client

## Getting started

### Environment Variables

These environment variables must be set in order to use access the API--

- QCI_TOKEN - token for Qatalyst API
<!-- markdown-link-check-disable-next-line -->
- QCI_API_URL - Example: "https://api.qci-prod.com"

### Installation

`qci-client` currently supports Python 3.8-11, as specified in the PEP-621-compliant
pyproject.toml.


Install `qci-client` from the [public PyPI server](https://pypi.org/)
into your Python virtual environment using--

```bash
pip install qci-client
```


